@@ -9,24 +9,24 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'BEOS_THREADS': 0,
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python2.7',
- 'BLDLIBRARY': '-L. -lpython2.7',
- 'BLDSHARED': 'gcc -pthread -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
- 'BUILDEXE': '',
- 'BUILDPYTHON': 'python',
- 'CC': 'gcc -pthread',
- 'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-aliasing -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -fno-plt',
- 'CFLAGSFORSHARED': '-fPIC',
+ 'BLDLIBRARY': 'libpython2.7.dll.a',
+ 'BLDSHARED': 'gcc -shared -Wl,--enable-auto-image-base -pipe -s  -L.',
+ 'BUILDEXE': '.exe',
+ 'BUILDPYTHON': 'python.exe',
+ 'CC': 'gcc',
+ 'CCSHARED': '',
+ 'CFLAGS': '-fno-strict-aliasing -march=x86-64 -mtune=generic -O2 -pipe -DNDEBUG  -DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -DNDEBUG',
+ 'CFLAGSFORSHARED': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
- 'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-threads' '--enable-optimizations' '--with-lto' '--enable-ipv6' '--enable-unicode=ucs4' '--with-system-expat' '--with-system-ffi' '--with-dbmliborder=gdbm:ndbm' '--without-ensurepip' 'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt' 'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' 'CPPFLAGS=-D_FORTIFY_SOURCE=2'",
+ 'CONFIG_ARGS': "'--build=x86_64-pc-msys' '--prefix=/usr' '--enable-shared' '--enable-ipv6' '--with-libc=' '--with-libm=' '--with-system-expat' '--with-system-ffi' '--with-threads' 'ac_cv_func_bind_textdomain_codeset=yes' 'CPPFLAGS= -I/usr/include/ncursesw' 'LDFLAGS=-pipe -s  -L.' 'build_alias=x86_64-pc-msys' 'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -DNDEBUG ' 'PKG_CONFIG_PATH=/usr/lib/pkgconfig:/usr/share/pkgconfig:/lib/pkgconfig'",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python2.7',
- 'COREPYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'COVERAGE_INFO': '/build/python2/src/Python-2.7.17/coverage.info',
- 'COVERAGE_REPORT': '/build/python2/src/Python-2.7.17/lcov-report',
+ 'COREPYTHONPATH': ':plat-msys:lib-tk:lib-old',
+ 'COVERAGE_INFO': '/msysdev/python2/src/Python-2.7.18/coverage.info',
+ 'COVERAGE_REPORT': '/msysdev/python2/src/Python-2.7.18/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov report"',
- 'CPPFLAGS': '-I. -IInclude -I./Include -D_FORTIFY_SOURCE=2',
- 'CXX': 'g++ -pthread',
+ 'CPPFLAGS': '-I. -IInclude -I./Include  -I/usr/include/ncursesw',
+ 'CXX': 'g++',
  'C_THREADS': 0,
  'DESTDIRS': '/usr /usr/lib /usr/lib/python2.7 /usr/lib/python2.7/lib-dynload',
  'DESTLIB': '/usr/lib/python2.7',
@@ -37,14 +37,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'DISTDIRS': 'Include Lib Misc Demo Ext-dummy',
  'DISTFILES': 'README ChangeLog configure configure.ac acconfig.h pyconfig.h.in Makefile.pre.in',
  'DLINCLDIR': '.',
- 'DLLLIBRARY': '',
+ 'DLLLIBRARY': 'msys-python2.7.dll',
  'DOUBLE_IS_ARM_MIXED_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_BIG_ENDIAN_IEEE754': 0,
  'DOUBLE_IS_LITTLE_ENDIAN_IEEE754': 1,
  'DYNLOADFILE': 'dynload_shlib.o',
  'ENABLE_IPV6': 1,
  'ENSUREPIP': 'no',
- 'EXE': '',
+ 'EXE': '.exe',
  'EXEMODE': 755,
  'EXTRAMACHDEPPATH': '',
  'EXTRAPLATDIR': '',
@@ -69,13 +69,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_ATANH': 1,
  'HAVE_ATTRIBUTE_FORMAT_PARSETUPLE': 0,
  'HAVE_BIND_TEXTDOMAIN_CODESET': 1,
- 'HAVE_BLUETOOTH_BLUETOOTH_H': 1,
+ 'HAVE_BLUETOOTH_BLUETOOTH_H': 0,
  'HAVE_BLUETOOTH_H': 0,
- 'HAVE_BROKEN_NICE': 0,
+ 'HAVE_BROKEN_NICE': 1,
  'HAVE_BROKEN_PIPE_BUF': 0,
  'HAVE_BROKEN_POLL': 0,
  'HAVE_BROKEN_POSIX_SEMAPHORES': 0,
- 'HAVE_BROKEN_PTHREAD_SIGMASK': 0,
+ 'HAVE_BROKEN_PTHREAD_SIGMASK': 1,
  'HAVE_BROKEN_SEM_GETVALUE': 0,
  'HAVE_BROKEN_UNSETENV': 0,
  'HAVE_C99_BOOL': 1,
@@ -115,7 +115,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_DLOPEN': 1,
  'HAVE_DUP2': 1,
  'HAVE_DYNAMIC_LOADING': 1,
- 'HAVE_EPOLL': 1,
+ 'HAVE_EPOLL': 0,
  'HAVE_ERF': 1,
  'HAVE_ERFC': 1,
  'HAVE_ERRNO_H': 1,
@@ -147,11 +147,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETC_UNLOCKED': 1,
  'HAVE_GETENTROPY': 1,
  'HAVE_GETGROUPS': 1,
- 'HAVE_GETHOSTBYNAME': 0,
- 'HAVE_GETHOSTBYNAME_R': 1,
+ 'HAVE_GETHOSTBYNAME': 1,
+ 'HAVE_GETHOSTBYNAME_R': 0,
  'HAVE_GETHOSTBYNAME_R_3_ARG': 0,
  'HAVE_GETHOSTBYNAME_R_5_ARG': 0,
- 'HAVE_GETHOSTBYNAME_R_6_ARG': 1,
+ 'HAVE_GETHOSTBYNAME_R_6_ARG': 0,
  'HAVE_GETITIMER': 1,
  'HAVE_GETLOADAVG': 1,
  'HAVE_GETLOGIN': 1,
@@ -163,24 +163,24 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_GETPID': 1,
  'HAVE_GETPRIORITY': 1,
  'HAVE_GETPWENT': 1,
- 'HAVE_GETRESGID': 1,
- 'HAVE_GETRESUID': 1,
+ 'HAVE_GETRESGID': 0,
+ 'HAVE_GETRESUID': 0,
  'HAVE_GETSID': 1,
- 'HAVE_GETSPENT': 1,
- 'HAVE_GETSPNAM': 1,
+ 'HAVE_GETSPENT': 0,
+ 'HAVE_GETSPNAM': 0,
  'HAVE_GETTIMEOFDAY': 1,
  'HAVE_GETWD': 1,
  'HAVE_GRP_H': 1,
  'HAVE_HSTRERROR': 1,
  'HAVE_HYPOT': 1,
- 'HAVE_IEEEFP_H': 0,
+ 'HAVE_IEEEFP_H': 1,
  'HAVE_INET_ATON': 1,
  'HAVE_INET_PTON': 1,
  'HAVE_INITGROUPS': 1,
  'HAVE_INT32_T': 1,
  'HAVE_INT64_T': 1,
  'HAVE_INTTYPES_H': 1,
- 'HAVE_IO_H': 0,
+ 'HAVE_IO_H': 1,
  'HAVE_KILL': 1,
  'HAVE_KILLPG': 1,
  'HAVE_KQUEUE': 0,
@@ -198,8 +198,8 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_LIBRESOLV': 0,
  'HAVE_LIBUTIL_H': 0,
  'HAVE_LINK': 1,
- 'HAVE_LINUX_NETLINK_H': 1,
- 'HAVE_LINUX_TIPC_H': 1,
+ 'HAVE_LINUX_NETLINK_H': 0,
+ 'HAVE_LINUX_TIPC_H': 0,
  'HAVE_LOG1P': 1,
  'HAVE_LONG_DOUBLE': 1,
  'HAVE_LONG_LONG': 1,
@@ -211,10 +211,10 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_MKNOD': 1,
  'HAVE_MKTIME': 1,
  'HAVE_MMAP': 1,
- 'HAVE_MREMAP': 1,
+ 'HAVE_MREMAP': 0,
  'HAVE_NCURSES_H': 1,
  'HAVE_NDIR_H': 0,
- 'HAVE_NETPACKET_PACKET_H': 1,
+ 'HAVE_NETPACKET_PACKET_H': 0,
  'HAVE_NICE': 1,
  'HAVE_OPENPTY': 1,
  'HAVE_OSX105_SDK': 0,
@@ -223,7 +223,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_PLOCK': 0,
  'HAVE_POLL': 1,
  'HAVE_POLL_H': 1,
- 'HAVE_PROCESS_H': 0,
+ 'HAVE_PROCESS_H': 1,
  'HAVE_PROTOTYPES': 1,
  'HAVE_PTH': 0,
  'HAVE_PTHREAD_ATFORK': 1,
@@ -258,13 +258,13 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SETPGID': 1,
  'HAVE_SETPGRP': 1,
  'HAVE_SETREGID': 1,
- 'HAVE_SETRESGID': 1,
- 'HAVE_SETRESUID': 1,
+ 'HAVE_SETRESGID': 0,
+ 'HAVE_SETRESUID': 0,
  'HAVE_SETREUID': 1,
  'HAVE_SETSID': 1,
  'HAVE_SETUID': 1,
  'HAVE_SETVBUF': 1,
- 'HAVE_SHADOW_H': 1,
+ 'HAVE_SHADOW_H': 0,
  'HAVE_SIGACTION': 1,
  'HAVE_SIGINTERRUPT': 1,
  'HAVE_SIGNAL_H': 1,
@@ -286,7 +286,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_STRINGS_H': 1,
  'HAVE_STRING_H': 1,
  'HAVE_STROPTS_H': 0,
- 'HAVE_STRUCT_STAT_ST_BIRTHTIME': 0,
+ 'HAVE_STRUCT_STAT_ST_BIRTHTIME': 1,
  'HAVE_STRUCT_STAT_ST_BLKSIZE': 1,
  'HAVE_STRUCT_STAT_ST_BLOCKS': 1,
  'HAVE_STRUCT_STAT_ST_FLAGS': 0,
@@ -299,11 +299,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SYS_AUDIOIO_H': 0,
  'HAVE_SYS_BSDTTY_H': 0,
  'HAVE_SYS_DIR_H': 0,
- 'HAVE_SYS_EPOLL_H': 1,
+ 'HAVE_SYS_EPOLL_H': 0,
  'HAVE_SYS_EVENT_H': 0,
  'HAVE_SYS_FILE_H': 1,
  'HAVE_SYS_LOADAVG_H': 0,
- 'HAVE_SYS_LOCK_H': 0,
+ 'HAVE_SYS_LOCK_H': 1,
  'HAVE_SYS_MKDEV_H': 0,
  'HAVE_SYS_MODEM_H': 0,
  'HAVE_SYS_NDIR_H': 0,
@@ -316,7 +316,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_SYS_STATVFS_H': 1,
  'HAVE_SYS_STAT_H': 1,
  'HAVE_SYS_SYSMACROS_H': 1,
- 'HAVE_SYS_TERMIO_H': 0,
+ 'HAVE_SYS_TERMIO_H': 1,
  'HAVE_SYS_TIMES_H': 1,
  'HAVE_SYS_TIME_H': 1,
  'HAVE_SYS_TYPES_H': 1,
@@ -334,7 +334,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_TIMES': 1,
  'HAVE_TMPFILE': 1,
  'HAVE_TMPNAM': 1,
- 'HAVE_TMPNAM_R': 1,
+ 'HAVE_TMPNAM_R': 0,
  'HAVE_TM_ZONE': 1,
  'HAVE_TRUNCATE': 1,
  'HAVE_TZNAME': 0,
@@ -345,7 +345,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_UNAME': 1,
  'HAVE_UNISTD_H': 1,
  'HAVE_UNSETENV': 1,
- 'HAVE_USABLE_WCHAR_T': 0,
+ 'HAVE_USABLE_WCHAR_T': 1,
  'HAVE_UTIL_H': 0,
  'HAVE_UTIMES': 1,
  'HAVE_UTIME_H': 1,
@@ -357,7 +357,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'HAVE_WORKING_TZSET': 1,
  'HAVE_ZLIB_COPY': 1,
  'HAVE__GETPTY': 0,
- 'HOST_GNU_TYPE': 'x86_64-pc-linux-gnu',
+ 'HOST_GNU_TYPE': 'x86_64-pc-msys',
  'HURD_C_THREADS': 0,
  'INCLDIRSTOMAKE': '/usr/include /usr/include /usr/include/python2.7 /usr/include/python2.7',
  'INCLUDEDIR': '/usr/include',
@@ -367,18 +367,18 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'INSTALL_PROGRAM': '/usr/bin/install -c',
  'INSTALL_SCRIPT': '/usr/bin/install -c',
  'INSTALL_SHARED': '/usr/bin/install -c -m 555',
- 'INSTSONAME': 'libpython2.7.so.1.0',
- 'LDCXXSHARED': 'g++ -pthread -shared',
- 'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'INSTSONAME': 'libpython2.7.dll.a',
+ 'LDCXXSHARED': 'g++ -shared -Wl,--enable-auto-image-base',
+ 'LDFLAGS': '-pipe -s  -L.',
  'LDLAST': '',
- 'LDLIBRARY': 'libpython2.7.so',
+ 'LDLIBRARY': 'libpython2.7.dll.a',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -pthread -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'LDSHARED': 'gcc -shared -Wl,--enable-auto-image-base -pipe -s  -L.',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python2.7',
  'LIBDIR': '/usr/lib',
- 'LIBFFI_INCLUDEDIR': '/usr/lib/libffi-3.2.1/include',
- 'LIBM': '-lm',
+ 'LIBFFI_INCLUDEDIR': '',
+ 'LIBM': '',
  'LIBOBJDIR': 'Python/',
  'LIBOBJS': '',
  'LIBP': '/usr/lib/python2.7',
@@ -386,25 +386,25 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'LIBPL': '/usr/lib/python2.7/config',
  'LIBRARY': 'libpython2.7.a',
  'LIBRARY_OBJS': '\\',
- 'LIBS': '-lpthread -ldl  -lutil',
+ 'LIBS': '-lintl -ldl',
  'LIBSUBDIRS': 'lib-tk lib-tk/test lib-tk/test/test_tkinter \\',
- 'LINKCC': 'gcc -pthread',
- 'LINKFORSHARED': '-Xlinker -export-dynamic',
+ 'LINKCC': 'gcc',
+ 'LINKFORSHARED': '',
  'LLVM_PROF_ERR': 'no',
  'LLVM_PROF_FILE': '',
  'LLVM_PROF_MERGER': 'true',
- 'LN': 'ln',
+ 'LN': 'cp -pR',
  'LOCALMODLIBS': '',
- 'MACHDEP': 'linux2',
- 'MACHDEPPATH': ':plat-linux2',
- 'MACHDEPS': 'plat-linux2',
+ 'MACHDEP': 'msys',
+ 'MACHDEPPATH': ':plat-msys',
+ 'MACHDEPS': 'plat-msys',
  'MACHDEP_OBJS': '',
  'MACHDESTLIB': '/usr/lib/python2.7',
  'MACH_C_THREADS': 0,
  'MACOSX_DEPLOYMENT_TARGET': '',
- 'MAINCC': 'gcc -pthread',
+ 'MAINCC': 'gcc',
  'MAJOR_IN_MKDEV': 0,
- 'MAJOR_IN_SYSMACROS': 1,
+ 'MAJOR_IN_SYSMACROS': 0,
  'MAKESETUP': './Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MEMTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\ -x test_dl test___all__ test_fork1 \\',
@@ -416,7 +416,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'MVWDELCH_IS_EXPRESSION': 1,
  'OBJECT_OBJS': '\\',
  'OLDPATH': ':lib-old',
- 'OPT': '-DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -fno-plt',
+ 'OPT': '-DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -DNDEBUG',
  'OTHER_LIBTOOL_OPT': '',
  'PACKAGE_BUGREPORT': 0,
  'PACKAGE_NAME': 0,
@@ -426,58 +426,58 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'PACKAGE_VERSION': 0,
  'PARSER_HEADERS': '\\',
  'PARSER_OBJS': '\\ Parser/myreadline.o Parser/tokenizer.o',
- 'PGEN': 'Parser/pgen',
+ 'PGEN': 'Parser/pgen.exe',
  'PGENOBJS': '\\ \\',
  'PGENSRCS': '\\ \\',
  'PGOBJS': '\\',
  'PGO_PROF_GEN_FLAG': '-fprofile-generate',
  'PGO_PROF_USE_FLAG': '-fprofile-use -fprofile-correction',
  'PGSRCS': '\\',
- 'PLATDIR': 'plat-linux2',
+ 'PLATDIR': 'plat-msys',
  'PLATMACDIRS': 'plat-mac plat-mac/Carbon plat-mac/lib-scriptpackages \\',
  'PLATMACPATH': ':plat-mac:plat-mac/lib-scriptpackages',
  'POBJS': '\\',
  'POSIX_SEMAPHORES_NOT_ENABLED': 0,
  'PROFILE_TASK': '-m test.regrtest --pgo -x test_asyncore test_gdb test_multiprocessing test_subprocess',
  'PSRCS': '\\',
- 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 1,
+ 'PTHREAD_SYSTEM_SCHED_SUPPORTED': 0,
  'PURIFY': '',
  'PYLONG_BITS_IN_DIGIT': 0,
- 'PYTHON': 'python',
+ 'PYTHON': 'python.exe',
  'PYTHONFRAMEWORK': '',
  'PYTHONFRAMEWORKDIR': 'no-framework',
  'PYTHONFRAMEWORKINSTALLDIR': '',
  'PYTHONFRAMEWORKPREFIX': '',
- 'PYTHONPATH': ':plat-linux2:lib-tk:lib-old',
- 'PYTHON_FOR_BUILD': './python -E',
- 'PYTHON_FOR_REGEN': 'python3',
+ 'PYTHONPATH': ':plat-msys:lib-tk:lib-old',
+ 'PYTHON_FOR_BUILD': './python.exe -E',
+ 'PYTHON_FOR_REGEN': 'python2.7',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
- 'PY_CFLAGS': '-fno-strict-aliasing -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -fno-plt -I. -IInclude -I./Include -D_FORTIFY_SOURCE=2 -fPIC -DPy_BUILD_CORE',
+ 'PY_CFLAGS': '-fno-strict-aliasing -march=x86-64 -mtune=generic -O2 -pipe -DNDEBUG  -DNDEBUG -march=x86-64 -mtune=generic -O2 -pipe -DNDEBUG -I. -IInclude -I./Include  -I/usr/include/ncursesw  -DPy_BUILD_CORE',
  'PY_FORMAT_LONG_LONG': '"ll"',
  'PY_FORMAT_SIZE_T': '"z"',
- 'PY_UNICODE_TYPE': 0,
+ 'PY_UNICODE_TYPE': 'wchar_t',
  'Py_DEBUG': 0,
  'Py_ENABLE_SHARED': 1,
- 'Py_UNICODE_SIZE': 4,
+ 'Py_UNICODE_SIZE': 2,
  'Py_USING_UNICODE': 1,
  'QUICKTESTOPTS': '-l -x test_subprocess test_io test_lib2to3 \\',
  'RANLIB': 'ranlib',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.17',
+ 'RUNSHARED': '',
  'SCRIPTDIR': '/usr/lib',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '',
  'SHELL': '/bin/sh',
- 'SHLIBS': '-lpthread -ldl  -lutil',
- 'SHLIB_EXT': '".so"',
+ 'SHLIBS': '-lintl -ldl',
+ 'SHLIB_EXT': '".dll"',
  'SIGNAL_OBJS': '',
  'SIGNED_RIGHT_SHIFT_ZERO_FILLS': 0,
  'SITEPATH': '',
  'SIZEOF_DOUBLE': 8,
  'SIZEOF_FLOAT': 4,
- 'SIZEOF_FPOS_T': 16,
+ 'SIZEOF_FPOS_T': 8,
  'SIZEOF_INT': 4,
  'SIZEOF_LONG': 8,
  'SIZEOF_LONG_DOUBLE': 16,
@@ -490,9 +490,9 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'SIZEOF_TIME_T': 8,
  'SIZEOF_UINTPTR_T': 8,
  'SIZEOF_VOID_P': 8,
- 'SIZEOF_WCHAR_T': 4,
+ 'SIZEOF_WCHAR_T': 2,
  'SIZEOF__BOOL': 1,
- 'SO': '.so',
+ 'SO': '.dll',
  'SRCDIRS': 'Parser Objects Python Modules Modules/_io',
  'SRC_GDB_HOOKS': './Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
@@ -500,7 +500,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'STRINGLIB_HEADERS': '\\',
  'SUBDIRS': '',
  'SUBDIRSTOO': 'Include Lib Misc Demo',
- 'SYSLIBS': '-lm',
+ 'SYSLIBS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TANH_PRESERVES_ZERO_SIGN': 1,
  'TCLTK_INCLUDES': '',
@@ -508,7 +508,7 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'TESTOPTS': '-l',
  'TESTPATH': '',
  'TESTPROG': './Lib/test/regrtest.py',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python2/src/Python-2.7.17 ./python -Wd -3 -E -tt',
+ 'TESTPYTHON': './python.exe -Wd -3 -E -tt',
  'TESTPYTHONOPTS': '',
  'THREADOBJ': 'Python/thread.o',
  'TIME_WITH_SYS_TIME': 1,
@@ -518,14 +518,14 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'UNIVERSALSDK': '',
  'USE_COMPUTED_GOTOS': 0,
  'USE_TOOLBOX_OBJECT_GLUE': 0,
- 'VA_LIST_IS_ARRAY': 1,
+ 'VA_LIST_IS_ARRAY': 0,
  'VERSION': '2.7',
  'WANT_SIGFPE_HANDLER': 0,
  'WANT_WCTYPE_FUNCTIONS': 0,
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DYLD': 0,
- 'WITH_LIBINTL': 0,
+ 'WITH_LIBINTL': 1,
  'WITH_NEXT_FRAMEWORK': 0,
  'WITH_PYMALLOC': 1,
  'WITH_THREAD': 1,
@@ -533,11 +533,11 @@ build_time_vars = {'AC_APPLE_UNIVERSAL_BUILD': 0,
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python2/src/Python-2.7.17',
- 'abs_srcdir': '/build/python2/src/Python-2.7.17',
- 'build': 'x86_64-pc-linux-gnu',
+ 'abs_builddir': '/msysdev/python2/src/Python-2.7.18',
+ 'abs_srcdir': '/msysdev/python2/src/Python-2.7.18',
+ 'build': 'x86_64-pc-msys',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
- 'host': 'x86_64-pc-linux-gnu',
+ 'host': 'x86_64-pc-msys',
  'prefix': '/usr',
  'srcdir': '.'}
